@@ -31,6 +31,7 @@ public:
 	ZLBooleanOption IsSensitiveOption;
 	ZLBooleanOption ShowTextPositionOption;
 	ZLBooleanOption ShowTimeOption;
+	ZLBooleanOption ShowFSToggleOption;
 	ZLColorOption ColorOption;
 	ZLIntegerRangeOption HeightOption;
 	ZLIntegerRangeOption OffsetOption;
@@ -43,6 +44,7 @@ public:
 	bool isSensitive() const;
 	bool isTextPositionShown() const;
 	bool isTimeShown() const;
+	bool isFSToggleShown() const;
 	ZLColor color() const;
 	int height() const;
 	int offset() const;
@@ -66,6 +68,7 @@ private:
 
 protected:
 	void doTapScrolling(int y);
+	void doLineScrolling(bool forward);
 
 public:
 	FBView(ZLPaintContext &context);
