@@ -327,6 +327,11 @@ const BookList &Library::books(shared_ptr<Tag> tag) const {
 	return myBooksByTag[tag];
 }
 
+const BookSet &Library::books() const {
+	synchronize();
+	return myBooks;
+}
+
 void Library::collectSeriesTitles(shared_ptr<Author> author, std::set<std::string> &titles) const {
 	const BookList &bookList = books(author);
 	for (BookList::const_iterator it = bookList.begin(); it != bookList.end(); ++it) {
