@@ -152,13 +152,16 @@ OptionsDialog::OptionsDialog() {
 
 	myDialog = ZLDialogManager::Instance().createOptionsDialog(ZLResourceKey("OptionsDialog"), new OptionsApplyRunnable(*this), true);
 
+	ZLDialogContent &startupTab = myDialog->createTab(ZLResourceKey("Startup"));
+	startupTab.addOption(ZLResourceKey("alwaysStartInLibrary"), fbreader.AlwaysStartInLibraryOption);
+	startupTab.addOption(ZLResourceKey("startFullscreen"), fbreader.StartFullscreenOption);
+
 	ZLDialogContent &libraryTab = myDialog->createTab(ZLResourceKey("Library"));
 	Library &library = Library::Instance();
 	libraryTab.addOption(ZLResourceKey("bookPath"), library.PathOption);
 	libraryTab.addOption(ZLResourceKey("lookInSubdirectories"), library.ScanSubdirsOption);
 	libraryTab.addOption(ZLResourceKey("collectBooksWithoutMetaInfo"), library.CollectAllBooksOption);
 	libraryTab.addOption(ZLResourceKey("downloadDirectory"), NetworkLinkCollection::Instance().DirectoryOption);
-	libraryTab.addOption(ZLResourceKey("alwaysStartInLibrary"), fbreader.AlwaysStartInLibraryOption);
 	libraryTab.addOption(ZLResourceKey("basicLibraryView"), library.BasicLibraryViewOption);
 
 	myNetworkLibraryPage = new NetworkLibraryPage(myDialog->createTab(ZLResourceKey("NetworkLibrary")));
